from typing import List

from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal import Conversions
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UserCls:
	"""User commands group definition. 4 total commands, 1 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("user", core, parent)

	@property
	def store(self):
		"""store commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_store'):
			from .Store import StoreCls
			self._store = StoreCls(self._core, self._cmd_group)
		return self._store

	def get_catalog(self) -> List[str]:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation:ENHanced:CHANnel:DPCH:CCODing:USER:CATalog \n
		Snippet: value: List[str] = driver.source.bb.w3Gpp.bstation.enhanced.channel.dpch.ccoding.user.get_catalog() \n
		Queries existing files with stored user channel codings. The files are stored with the fixed file extensions *.3g_ccod_dl
		in a directory of the user's choice. The directory applicable to the commands is defined with the command method RsSmbv.
		MassMemory.currentDirectory. \n
			:return: catalog: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:W3GPp:BSTation:ENHanced:CHANnel:DPCH:CCODing:USER:CATalog?')
		return Conversions.str_to_str_list(response)

	def delete(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation:ENHanced:CHANnel:DPCH:CCODing:USER:DELete \n
		Snippet: driver.source.bb.w3Gpp.bstation.enhanced.channel.dpch.ccoding.user.delete(filename = 'abc') \n
		Deletes the specified files with stored user channel codings. The files are stored with the fixed file extensions *.
		3g_ccod_dl in a directory of the user's choice. The directory applicable to the commands is defined with the command
		method RsSmbv.MassMemory.currentDirectory. To access the files in this directory, you only have to give the file name,
		without the path and the file extension. \n
			:param filename: string
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:BSTation:ENHanced:CHANnel:DPCH:CCODing:USER:DELete {param}')

	def load(self, filename: str, channelNull=repcap.ChannelNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation:ENHanced:CHANnel<CH0>:DPCH:CCODing:USER:LOAD \n
		Snippet: driver.source.bb.w3Gpp.bstation.enhanced.channel.dpch.ccoding.user.load(filename = 'abc', channelNull = repcap.ChannelNull.Default) \n
		The command loads the specified files with stored user channel codings. The files are stored with the fixed file
		extensions *.3g_ccod_dl in a directory of the user's choice. The directory applicable to the commands is defined with the
		command method RsSmbv.MassMemory.currentDirectory. To access the files in this directory, you only have to give the file
		name, without the path and the file extension. \n
			:param filename: user_coding
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')
		"""
		param = Conversions.value_to_quoted_str(filename)
		channelNull_cmd_val = self._cmd_group.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:BSTation:ENHanced:CHANnel{channelNull_cmd_val}:DPCH:CCODing:USER:LOAD {param}')

	def clone(self) -> 'UserCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = UserCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class N2IdCls:
	"""N2Id commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("n2Id", core, parent)

	def get(self, cellNull=repcap.CellNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:NR5G:NODE:CELL<CC(CH0)>:N2ID \n
		Snippet: value: int = driver.source.bb.nr5G.node.cell.n2Id.get(cellNull = repcap.CellNull.Default) \n
		Queries the physical layer indicator group (NID(2) ). (Sidelink: NID,2SL) \n
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:return: carrier_n_2_id: integer Range: 0 to 2"""
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:NODE:CELL{cellNull_cmd_val}:N2ID?')
		return Conversions.str_to_int(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EnhCls:
	"""Enh commands group definition. 106 total commands, 2 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("enh", core, parent)

	@property
	def bch(self):
		"""bch commands group. 7 Sub-classes, 0 commands."""
		if not hasattr(self, '_bch'):
			from .Bch import BchCls
			self._bch = BchCls(self._core, self._cmd_group)
		return self._bch

	@property
	def dch(self):
		"""dch commands group. 17 Sub-classes, 0 commands."""
		if not hasattr(self, '_dch'):
			from .Dch import DchCls
			self._dch = DchCls(self._core, self._cmd_group)
		return self._dch

	def clone(self) -> 'EnhCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = EnhCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DataCls:
	"""Data commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("data", core, parent)

	def get_dselection(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:HUWB:STS:DATA:DSELection \n
		Snippet: value: str = driver.source.bb.huwb.sts.data.get_dselection() \n
		Selects an existing data list file from the default directory or from a specific directory. The data list is only used,
		if DLS is activated. \n
			:return: sts_dlist: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:HUWB:STS:DATA:DSELection?')
		return trim_str_response(response)

	def set_dselection(self, sts_dlist: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:HUWB:STS:DATA:DSELection \n
		Snippet: driver.source.bb.huwb.sts.data.set_dselection(sts_dlist = 'abc') \n
		Selects an existing data list file from the default directory or from a specific directory. The data list is only used,
		if DLS is activated. \n
			:param sts_dlist: string
		"""
		param = Conversions.value_to_quoted_str(sts_dlist)
		self._core.io.write(f'SOURce<HwInstance>:BB:HUWB:STS:DATA:DSELection {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AnetworkCls:
	"""Anetwork commands group definition. 14 total commands, 3 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("anetwork", core, parent)

	@property
	def cchannel(self):
		"""cchannel commands group. 1 Sub-classes, 3 commands."""
		if not hasattr(self, '_cchannel'):
			from .Cchannel import CchannelCls
			self._cchannel = CchannelCls(self._core, self._cmd_group)
		return self._cchannel

	@property
	def pchannel(self):
		"""pchannel commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pchannel'):
			from .Pchannel import PchannelCls
			self._pchannel = PchannelCls(self._core, self._cmd_group)
		return self._pchannel

	@property
	def rab(self):
		"""rab commands group. 1 Sub-classes, 4 commands."""
		if not hasattr(self, '_rab'):
			from .Rab import RabCls
			self._rab = RabCls(self._core, self._cmd_group)
		return self._rab

	def get_cp_mode(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EVDO:ANETwork:CPMode \n
		Snippet: value: bool = driver.source.bb.evdo.anetwork.get_cp_mode() \n
		Enables or disables a special mode within the 1xEV-DO generator. Note: During the special mode, all other parameters do
		not affect the signal output. \n
			:return: cp_mode: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EVDO:ANETwork:CPMode?')
		return Conversions.str_to_bool(response)

	def set_cp_mode(self, cp_mode: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:EVDO:ANETwork:CPMode \n
		Snippet: driver.source.bb.evdo.anetwork.set_cp_mode(cp_mode = False) \n
		Enables or disables a special mode within the 1xEV-DO generator. Note: During the special mode, all other parameters do
		not affect the signal output. \n
			:param cp_mode: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(cp_mode)
		self._core.io.write(f'SOURce<HwInstance>:BB:EVDO:ANETwork:CPMode {param}')

	def get_ou_count(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:EVDO:ANETwork:OUCount \n
		Snippet: value: int = driver.source.bb.evdo.anetwork.get_ou_count() \n
		Sets the number of additional users (beyond the four defined users) that appear in the MAC Channel. \n
			:return: ou_count: integer Range: 0 to 55 for physical layer subtype 0&1) , 0 to 110 for physical layer subtype 2, 0 to 360 for physical layer subtype 3
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EVDO:ANETwork:OUCount?')
		return Conversions.str_to_int(response)

	def set_ou_count(self, ou_count: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:EVDO:ANETwork:OUCount \n
		Snippet: driver.source.bb.evdo.anetwork.set_ou_count(ou_count = 1) \n
		Sets the number of additional users (beyond the four defined users) that appear in the MAC Channel. \n
			:param ou_count: integer Range: 0 to 55 for physical layer subtype 0&1) , 0 to 110 for physical layer subtype 2, 0 to 360 for physical layer subtype 3
		"""
		param = Conversions.decimal_value_to_str(ou_count)
		self._core.io.write(f'SOURce<HwInstance>:BB:EVDO:ANETwork:OUCount {param}')

	# noinspection PyTypeChecker
	def get_sub_type(self) -> enums.EvdoLayerDn:
		"""SCPI: [SOURce<HW>]:BB:EVDO:ANETwork:SUBType \n
		Snippet: value: enums.EvdoLayerDn = driver.source.bb.evdo.anetwork.get_sub_type() \n
		Selects the physical layer subtype. Note: The physical layer subtype settings can be queried per user. \n
			:return: sub_type: S1| S2| S3
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EVDO:ANETwork:SUBType?')
		return Conversions.str_to_scalar_enum(response, enums.EvdoLayerDn)

	def set_sub_type(self, sub_type: enums.EvdoLayerDn) -> None:
		"""SCPI: [SOURce<HW>]:BB:EVDO:ANETwork:SUBType \n
		Snippet: driver.source.bb.evdo.anetwork.set_sub_type(sub_type = enums.EvdoLayerDn.S1) \n
		Selects the physical layer subtype. Note: The physical layer subtype settings can be queried per user. \n
			:param sub_type: S1| S2| S3
		"""
		param = Conversions.enum_scalar_to_str(sub_type, enums.EvdoLayerDn)
		self._core.io.write(f'SOURce<HwInstance>:BB:EVDO:ANETwork:SUBType {param}')

	def clone(self) -> 'AnetworkCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AnetworkCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SconfigurationCls:
	"""Sconfiguration commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sconfiguration", core, parent)

	def get_tn_samples(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:NFC:SCONfiguration:TNSamples \n
		Snippet: value: int = driver.source.bb.nfc.sconfiguration.get_tn_samples() \n
		Queries the total number of samples allocated to the current frame. \n
			:return: tn_samples: integer
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NFC:SCONfiguration:TNSamples?')
		return Conversions.str_to_int(response)

	def get_ts_duration(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:NFC:SCONfiguration:TSDuration \n
		Snippet: value: float = driver.source.bb.nfc.sconfiguration.get_ts_duration() \n
		Queries the total sequence duration for the current settings. \n
			:return: ts_duration: float
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NFC:SCONfiguration:TSDuration?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EofCls:
	"""Eof commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("eof", core, parent)

	def set(self, mpdu_eof: enums.WlannFbMpduEof, frameBlock=repcap.FrameBlock.Default, userIx=repcap.UserIx.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:[USER<DI>]:TFConfig:EOF \n
		Snippet: driver.source.bb.wlnn.fblock.user.tfConfig.eof.set(mpdu_eof = enums.WlannFbMpduEof.E0, frameBlock = repcap.FrameBlock.Default, userIx = repcap.UserIx.Default) \n
		Selects the end of frame (EOF) tag. Tagged/untagged indication is set in the 1-bit EOF/Tag field of an MPDU. \n
			:param mpdu_eof: E0| E1 E0 End of frame is untagged. E1 End of frame is tagged.
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
		"""
		param = Conversions.enum_scalar_to_str(mpdu_eof, enums.WlannFbMpduEof)
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:USER{userIx_cmd_val}:TFConfig:EOF {param}')

	# noinspection PyTypeChecker
	def get(self, frameBlock=repcap.FrameBlock.Default, userIx=repcap.UserIx.Default) -> enums.WlannFbMpduEof:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:[USER<DI>]:TFConfig:EOF \n
		Snippet: value: enums.WlannFbMpduEof = driver.source.bb.wlnn.fblock.user.tfConfig.eof.get(frameBlock = repcap.FrameBlock.Default, userIx = repcap.UserIx.Default) \n
		Selects the end of frame (EOF) tag. Tagged/untagged indication is set in the 1-bit EOF/Tag field of an MPDU. \n
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:return: mpdu_eof: E0| E1 E0 End of frame is untagged. E1 End of frame is tagged."""
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:USER{userIx_cmd_val}:TFConfig:EOF?')
		return Conversions.str_to_scalar_enum(response, enums.WlannFbMpduEof)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FrequencyCls:
	"""Frequency commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("frequency", core, parent)

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.AvionicCarrFreqMode:
		"""SCPI: [SOURce<HW>]:[BB]:ILS:LOCalizer:FREQuency:MODE \n
		Snippet: value: enums.AvionicCarrFreqMode = driver.source.bb.ils.localizer.frequency.get_mode() \n
		Sets the mode for the carrier frequency of the signal. \n
			:return: ils_loc_freq_mode: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ILS:LOCalizer:FREQuency:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.AvionicCarrFreqMode)

	def set_mode(self, ils_loc_freq_mode: enums.AvionicCarrFreqMode) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:ILS:LOCalizer:FREQuency:MODE \n
		Snippet: driver.source.bb.ils.localizer.frequency.set_mode(ils_loc_freq_mode = enums.AvionicCarrFreqMode.DECimal) \n
		Sets the mode for the carrier frequency of the signal. \n
			:param ils_loc_freq_mode: DECimal| ICAO DECimal Activates user-defined variation of the carrier frequency. ICAO Activates variation in predefined steps according to standard ILS transmitting frequencies (see Table 'ILS ICAO channels and frequencies (MHz) ') .
		"""
		param = Conversions.enum_scalar_to_str(ils_loc_freq_mode, enums.AvionicCarrFreqMode)
		self._core.io.write(f'SOURce<HwInstance>:BB:ILS:LOCalizer:FREQuency:MODE {param}')

	def get_value(self) -> float:
		"""SCPI: [SOURce<HW>]:[BB]:ILS:LOCalizer:FREQuency \n
		Snippet: value: float = driver.source.bb.ils.localizer.frequency.get_value() \n
		Sets the carrier frequency of the signal. \n
			:return: carrier_freq: float Range: 100E3 to 6E9
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ILS:LOCalizer:FREQuency?')
		return Conversions.str_to_float(response)

	def set_value(self, carrier_freq: float) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:ILS:LOCalizer:FREQuency \n
		Snippet: driver.source.bb.ils.localizer.frequency.set_value(carrier_freq = 1.0) \n
		Sets the carrier frequency of the signal. \n
			:param carrier_freq: float Range: 100E3 to 6E9
		"""
		param = Conversions.decimal_value_to_str(carrier_freq)
		self._core.io.write(f'SOURce<HwInstance>:BB:ILS:LOCalizer:FREQuency {param}')



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TcrCls:
	"""Tcr commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("tcr", core, parent)

	def set(self, target_cr: float, userIx=repcap.UserIx.Default, cellNull=repcap.CellNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:USER<CH>:AS:DL:CELL<ST0>:TCR \n
		Snippet: driver.source.bb.eutra.downlink.user.asPy.downlink.cell.tcr.set(target_cr = 1.0, userIx = repcap.UserIx.Default, cellNull = repcap.CellNull.Default) \n
		Sets the target code rate. \n
			:param target_cr: float Range: 0 to 1
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
		"""
		param = Conversions.decimal_value_to_str(target_cr)
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:USER{userIx_cmd_val}:AS:DL:CELL{cellNull_cmd_val}:TCR {param}')

	def get(self, userIx=repcap.UserIx.Default, cellNull=repcap.CellNull.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:USER<CH>:AS:DL:CELL<ST0>:TCR \n
		Snippet: value: float = driver.source.bb.eutra.downlink.user.asPy.downlink.cell.tcr.get(userIx = repcap.UserIx.Default, cellNull = repcap.CellNull.Default) \n
		Sets the target code rate. \n
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:return: target_cr: float Range: 0 to 1"""
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:USER{userIx_cmd_val}:AS:DL:CELL{cellNull_cmd_val}:TCR?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RepetitionCls:
	"""Repetition commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("repetition", core, parent)

	def get_points(self) -> int:
		"""SCPI: [SOURce<HW>]:PULM:TRAin:REPetition:POINts \n
		Snippet: value: int = driver.source.pulm.train.repetition.get_points() \n
		Queries the number of on and off time entries and repetitions in the selected list. \n
			:return: points: integer Range: 0 to INT_MAX
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:PULM:TRAin:REPetition:POINts?')
		return Conversions.str_to_int(response)

	def get_value(self) -> str:
		"""SCPI: [SOURce<HW>]:PULM:TRAin:REPetition \n
		Snippet: value: str = driver.source.pulm.train.repetition.get_value() \n
		Sets the number of repetitions for each pulse on/off time value pair. \n
			:return: repetition: Repetition#1{, Repetition#2, ...} 0 = ignore value pair Set 'Repetition = 0' to skip a particular pulse without deleting the pulse on/off time value pair Range: 0 to 65535
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:PULM:TRAin:REPetition?')
		return trim_str_response(response)

	def set_value(self, repetition: str) -> None:
		"""SCPI: [SOURce<HW>]:PULM:TRAin:REPetition \n
		Snippet: driver.source.pulm.train.repetition.set_value(repetition = 'abc') \n
		Sets the number of repetitions for each pulse on/off time value pair. \n
			:param repetition: Repetition#1{, Repetition#2, ...} 0 = ignore value pair Set 'Repetition = 0' to skip a particular pulse without deleting the pulse on/off time value pair Range: 0 to 65535
		"""
		param = Conversions.value_to_quoted_str(repetition)
		self._core.io.write(f'SOURce<HwInstance>:PULM:TRAin:REPetition {param}')



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Utilities import trim_str_response
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MglCls:
	"""Mgl commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mgl", core, parent)

	def set(self, mfsi_gid_l: str, frameBlock=repcap.FrameBlock.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:MAC:VHTControl:MGL \n
		Snippet: driver.source.bb.wlnn.fblock.mac.vhtControl.mgl.set(mfsi_gid_l = rawAbc, frameBlock = repcap.FrameBlock.Default) \n
		The command determines the information of the MFSI/GID-L subfield. MFB = 0 If the Unsolicited MFB subfield is set to 0,
		the MFSI/GID-L subfield contains the received value of MSI contained in the frame to which the MFB information refers.
		MFB = 1 The MFSI/GID-L subfield contains the lowest 3 bits of Group ID of the PPDU to which the unsolicited MFB refers. \n
			:param mfsi_gid_l: integer
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
		"""
		param = Conversions.value_to_str(mfsi_gid_l)
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:MAC:VHTControl:MGL {param}')

	def get(self, frameBlock=repcap.FrameBlock.Default) -> str:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:MAC:VHTControl:MGL \n
		Snippet: value: str = driver.source.bb.wlnn.fblock.mac.vhtControl.mgl.get(frameBlock = repcap.FrameBlock.Default) \n
		The command determines the information of the MFSI/GID-L subfield. MFB = 0 If the Unsolicited MFB subfield is set to 0,
		the MFSI/GID-L subfield contains the received value of MSI contained in the frame to which the MFB information refers.
		MFB = 1 The MFSI/GID-L subfield contains the lowest 3 bits of Group ID of the PPDU to which the unsolicited MFB refers. \n
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:return: mfsi_gid_l: integer"""
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:MAC:VHTControl:MGL?')
		return trim_str_response(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Nr5GCls:
	"""Nr5G commands group definition. 1456 total commands, 27 Subgroups, 7 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("nr5G", core, parent)

	@property
	def analyzer(self):
		"""analyzer commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_analyzer'):
			from .Analyzer import AnalyzerCls
			self._analyzer = AnalyzerCls(self._core, self._cmd_group)
		return self._analyzer

	@property
	def cbwx(self):
		"""cbwx commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cbwx'):
			from .Cbwx import CbwxCls
			self._cbwx = CbwxCls(self._core, self._cmd_group)
		return self._cbwx

	@property
	def clock(self):
		"""clock commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_clock'):
			from .Clock import ClockCls
			self._clock = ClockCls(self._core, self._cmd_group)
		return self._clock

	@property
	def feature(self):
		"""feature commands group. 1 Sub-classes, 2 commands."""
		if not hasattr(self, '_feature'):
			from .Feature import FeatureCls
			self._feature = FeatureCls(self._core, self._cmd_group)
		return self._feature

	@property
	def fmode(self):
		"""fmode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fmode'):
			from .Fmode import FmodeCls
			self._fmode = FmodeCls(self._core, self._cmd_group)
		return self._fmode

	@property
	def hfb(self):
		"""hfb commands group. 1 Sub-classes, 12 commands."""
		if not hasattr(self, '_hfb'):
			from .Hfb import HfbCls
			self._hfb = HfbCls(self._core, self._cmd_group)
		return self._hfb

	@property
	def k145(self):
		"""k145 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_k145'):
			from .K145 import K145Cls
			self._k145 = K145Cls(self._core, self._cmd_group)
		return self._k145

	@property
	def k148(self):
		"""k148 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_k148'):
			from .K148 import K148Cls
			self._k148 = K148Cls(self._core, self._cmd_group)
		return self._k148

	@property
	def k171(self):
		"""k171 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_k171'):
			from .K171 import K171Cls
			self._k171 = K171Cls(self._core, self._cmd_group)
		return self._k171

	@property
	def k175(self):
		"""k175 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_k175'):
			from .K175 import K175Cls
			self._k175 = K175Cls(self._core, self._cmd_group)
		return self._k175

	@property
	def k548(self):
		"""k548 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_k548'):
			from .K548 import K548Cls
			self._k548 = K548Cls(self._core, self._cmd_group)
		return self._k548

	@property
	def k81(self):
		"""k81 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_k81'):
			from .K81 import K81Cls
			self._k81 = K81Cls(self._core, self._cmd_group)
		return self._k81

	@property
	def logGen(self):
		"""logGen commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_logGen'):
			from .LogGen import LogGenCls
			self._logGen = LogGenCls(self._core, self._cmd_group)
		return self._logGen

	@property
	def node(self):
		"""node commands group. 4 Sub-classes, 1 commands."""
		if not hasattr(self, '_node'):
			from .Node import NodeCls
			self._node = NodeCls(self._core, self._cmd_group)
		return self._node

	@property
	def nsmod(self):
		"""nsmod commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nsmod'):
			from .Nsmod import NsmodCls
			self._nsmod = NsmodCls(self._core, self._cmd_group)
		return self._nsmod

	@property
	def output(self):
		"""output commands group. 6 Sub-classes, 7 commands."""
		if not hasattr(self, '_output'):
			from .Output import OutputCls
			self._output = OutputCls(self._core, self._cmd_group)
		return self._output

	@property
	def qckset(self):
		"""qckset commands group. 4 Sub-classes, 1 commands."""
		if not hasattr(self, '_qckset'):
			from .Qckset import QcksetCls
			self._qckset = QcksetCls(self._core, self._cmd_group)
		return self._qckset

	@property
	def sanity(self):
		"""sanity commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_sanity'):
			from .Sanity import SanityCls
			self._sanity = SanityCls(self._core, self._cmd_group)
		return self._sanity

	@property
	def scheduling(self):
		"""scheduling commands group. 2 Sub-classes, 3 commands."""
		if not hasattr(self, '_scheduling'):
			from .Scheduling import SchedulingCls
			self._scheduling = SchedulingCls(self._core, self._cmd_group)
		return self._scheduling

	@property
	def setting(self):
		"""setting commands group. 2 Sub-classes, 4 commands."""
		if not hasattr(self, '_setting'):
			from .Setting import SettingCls
			self._setting = SettingCls(self._core, self._cmd_group)
		return self._setting

	@property
	def symbolRate(self):
		"""symbolRate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_symbolRate'):
			from .SymbolRate import SymbolRateCls
			self._symbolRate = SymbolRateCls(self._core, self._cmd_group)
		return self._symbolRate

	@property
	def tcw(self):
		"""tcw commands group. 11 Sub-classes, 16 commands."""
		if not hasattr(self, '_tcw'):
			from .Tcw import TcwCls
			self._tcw = TcwCls(self._core, self._cmd_group)
		return self._tcw

	@property
	def tdWind(self):
		"""tdWind commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tdWind'):
			from .TdWind import TdWindCls
			self._tdWind = TdWindCls(self._core, self._cmd_group)
		return self._tdWind

	@property
	def trigger(self):
		"""trigger commands group. 7 Sub-classes, 5 commands."""
		if not hasattr(self, '_trigger'):
			from .Trigger import TriggerCls
			self._trigger = TriggerCls(self._core, self._cmd_group)
		return self._trigger

	@property
	def ubwp(self):
		"""ubwp commands group. 2 Sub-classes, 3 commands."""
		if not hasattr(self, '_ubwp'):
			from .Ubwp import UbwpCls
			self._ubwp = UbwpCls(self._core, self._cmd_group)
		return self._ubwp

	@property
	def uplane(self):
		"""uplane commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_uplane'):
			from .Uplane import UplaneCls
			self._uplane = UplaneCls(self._core, self._cmd_group)
		return self._uplane

	@property
	def waveform(self):
		"""waveform commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_waveform'):
			from .Waveform import WaveformCls
			self._waveform = WaveformCls(self._core, self._cmd_group)
		return self._waveform

	# noinspection PyTypeChecker
	def get_link(self) -> enums.LinkDir2:
		"""SCPI: [SOURce<HW>]:BB:NR5G:LINK \n
		Snippet: value: enums.LinkDir2 = driver.source.bb.nr5G.get_link() \n
		Selects the transmission direction. \n
			:return: link_dir: DOWN | SIDE | UP DOWN Selects downlink direction. SIDE Selects sidelink direction. Requires Option: R&S SMBVB-K170 UP Selects downlink direction.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:LINK?')
		return Conversions.str_to_scalar_enum(response, enums.LinkDir2)

	def set_link(self, link_dir: enums.LinkDir2) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:LINK \n
		Snippet: driver.source.bb.nr5G.set_link(link_dir = enums.LinkDir2.DOWN) \n
		Selects the transmission direction. \n
			:param link_dir: DOWN | SIDE | UP DOWN Selects downlink direction. SIDE Selects sidelink direction. Requires Option: R&S SMBVB-K170 UP Selects downlink direction.
		"""
		param = Conversions.enum_scalar_to_str(link_dir, enums.LinkDir2)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:LINK {param}')

	# noinspection PyTypeChecker
	def get_map_coord(self) -> enums.CoordMapMode:
		"""SCPI: [SOURce<HW>]:BB:NR5G:MAPCoord \n
		Snippet: value: enums.CoordMapMode = driver.source.bb.nr5G.get_map_coord() \n
		No command help available \n
			:return: coord_map_mode: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:MAPCoord?')
		return Conversions.str_to_scalar_enum(response, enums.CoordMapMode)

	def set_map_coord(self, coord_map_mode: enums.CoordMapMode) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:MAPCoord \n
		Snippet: driver.source.bb.nr5G.set_map_coord(coord_map_mode = enums.CoordMapMode.CARTesian) \n
		No command help available \n
			:param coord_map_mode: No help available
		"""
		param = Conversions.enum_scalar_to_str(coord_map_mode, enums.CoordMapMode)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:MAPCoord {param}')

	def get_pl_version(self) -> str:
		"""SCPI: [SOURce]:BB:NR5G:PLVersion \n
		Snippet: value: str = driver.source.bb.nr5G.get_pl_version() \n
		Queries the installed version of the 5G New Radio application. \n
			:return: plugin_version: string
		"""
		response = self._core.io.query_str('SOURce:BB:NR5G:PLVersion?')
		return trim_str_response(response)

	def preset(self) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:PRESet \n
		Snippet: driver.source.bb.nr5G.preset() \n
		Sets the parameters of the digital standard to their default values (*RST values specified for the commands) .
		Not affected is the state set with the command SOURce<hw>:BB:NR5G:STATe. \n
		"""
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:PRESet')

	def preset_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:PRESet \n
		Snippet: driver.source.bb.nr5G.preset_with_opc() \n
		Sets the parameters of the digital standard to their default values (*RST values specified for the commands) .
		Not affected is the state set with the command SOURce<hw>:BB:NR5G:STATe. \n
		Same as preset, but waits for the operation to complete before continuing further. Use the RsSmbv.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:BB:NR5G:PRESet', opc_timeout_ms)

	def get_simple(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:NR5G:SIMPle \n
		Snippet: value: bool = driver.source.bb.nr5G.get_simple() \n
		Turns the simple mode of the user interface on and off. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:SIMPle?')
		return Conversions.str_to_bool(response)

	def set_simple(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:SIMPle \n
		Snippet: driver.source.bb.nr5G.set_simple(state = False) \n
		Turns the simple mode of the user interface on and off. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:SIMPle {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:NR5G:STATe \n
		Snippet: value: bool = driver.source.bb.nr5G.get_state() \n
		Activates the standard and deactivates all the other digital standards and digital modulation modes in the same path. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:STATe \n
		Snippet: driver.source.bb.nr5G.set_state(state = False) \n
		Activates the standard and deactivates all the other digital standards and digital modulation modes in the same path. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:STATe {param}')

	def get_version(self) -> str:
		"""SCPI: [SOURce]:BB:NR5G:VERSion \n
		Snippet: value: str = driver.source.bb.nr5G.get_version() \n
		Queries the version of the 3GPP standard underlying the definitions. \n
			:return: version: string
		"""
		response = self._core.io.query_str('SOURce:BB:NR5G:VERSion?')
		return trim_str_response(response)

	def clone(self) -> 'Nr5GCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Nr5GCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal import Conversions
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ImaginaryCls:
	"""Imaginary commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("imaginary", core, parent)

	def set(self, ant_port_map_dat: float, antennaPortNull=repcap.AntennaPortNull.Default, row=repcap.Row.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:MIMO:APM:CS:AP<DIR0>:ROW<ST0>:IMAGinary \n
		Snippet: driver.source.bb.eutra.downlink.mimo.apm.cs.ap.row.imaginary.set(ant_port_map_dat = 1.0, antennaPortNull = repcap.AntennaPortNull.Default, row = repcap.Row.Default) \n
		Define the mapping of the antenna ports to the physical antennas. \n
			:param ant_port_map_dat: float The REAL (Magnitude) and IMAGinary (Phase) values are interdependent. Their value ranges change depending on each other and so that the resulting complex value is as follows: |REAL+j*IMAGinary| <= 1 Otherwise, the values are normalized to Magnitude = 1. Range: -1 to 360
			:param antennaPortNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Ap')
			:param row: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Row')
		"""
		param = Conversions.decimal_value_to_str(ant_port_map_dat)
		antennaPortNull_cmd_val = self._cmd_group.get_repcap_cmd_value(antennaPortNull, repcap.AntennaPortNull)
		row_cmd_val = self._cmd_group.get_repcap_cmd_value(row, repcap.Row)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:MIMO:APM:CS:AP{antennaPortNull_cmd_val}:ROW{row_cmd_val}:IMAGinary {param}')

	def get(self, antennaPortNull=repcap.AntennaPortNull.Default, row=repcap.Row.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:MIMO:APM:CS:AP<DIR0>:ROW<ST0>:IMAGinary \n
		Snippet: value: float = driver.source.bb.eutra.downlink.mimo.apm.cs.ap.row.imaginary.get(antennaPortNull = repcap.AntennaPortNull.Default, row = repcap.Row.Default) \n
		Define the mapping of the antenna ports to the physical antennas. \n
			:param antennaPortNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Ap')
			:param row: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Row')
			:return: ant_port_map_dat: float The REAL (Magnitude) and IMAGinary (Phase) values are interdependent. Their value ranges change depending on each other and so that the resulting complex value is as follows: |REAL+j*IMAGinary| <= 1 Otherwise, the values are normalized to Magnitude = 1. Range: -1 to 360"""
		antennaPortNull_cmd_val = self._cmd_group.get_repcap_cmd_value(antennaPortNull, repcap.AntennaPortNull)
		row_cmd_val = self._cmd_group.get_repcap_cmd_value(row, repcap.Row)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:MIMO:APM:CS:AP{antennaPortNull_cmd_val}:ROW{row_cmd_val}:IMAGinary?')
		return Conversions.str_to_float(response)



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PdcchCls:
	"""Pdcch commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pdcch", core, parent)

	@property
	def nmAdaption(self):
		"""nmAdaption commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nmAdaption'):
			from .NmAdaption import NmAdaptionCls
			self._nmAdaption = NmAdaptionCls(self._core, self._cmd_group)
		return self._nmAdaption

	@property
	def nt3C(self):
		"""nt3C commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nt3C'):
			from .Nt3C import Nt3CCls
			self._nt3C = Nt3CCls(self._core, self._cmd_group)
		return self._nt3C

	@property
	def numPreempt(self):
		"""numPreempt commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_numPreempt'):
			from .NumPreempt import NumPreemptCls
			self._numPreempt = NumPreemptCls(self._core, self._cmd_group)
		return self._numPreempt

	def clone(self) -> 'PdcchCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PdcchCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OptimizationCls:
	"""Optimization commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("optimization", core, parent)

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.OptimizationMode:
		"""SCPI: [SOURce<HW>]:BB:IMPairment:OPTimization:MODE \n
		Snippet: value: enums.OptimizationMode = driver.source.bb.impairment.optimization.get_mode() \n
		Sets the optimization mode. \n
			:return: mode: FAST| | QHIGh FAST Optimization by compensation for I/Q skew. QHIGh Optimization by compensation for I/Q skew and frequency response correction. This mode interrupts the RF signal. Do not use it in combination with the uninterrupted level settings and strictly monotone modes RF level modes. (See [:SOURcehw]:POWer:LBEHaviour.)
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:IMPairment:OPTimization:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.OptimizationMode)

	def set_mode(self, mode: enums.OptimizationMode) -> None:
		"""SCPI: [SOURce<HW>]:BB:IMPairment:OPTimization:MODE \n
		Snippet: driver.source.bb.impairment.optimization.set_mode(mode = enums.OptimizationMode.FAST) \n
		Sets the optimization mode. \n
			:param mode: FAST| | QHIGh FAST Optimization by compensation for I/Q skew. QHIGh Optimization by compensation for I/Q skew and frequency response correction. This mode interrupts the RF signal. Do not use it in combination with the uninterrupted level settings and strictly monotone modes RF level modes. (See [:SOURcehw]:POWer:LBEHaviour.)
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.OptimizationMode)
		self._core.io.write(f'SOURce<HwInstance>:BB:IMPairment:OPTimization:MODE {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:IMPairment:OPTimization:STATe \n
		Snippet: value: bool = driver.source.bb.impairment.optimization.get_state() \n
		No command help available \n
			:return: state: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:IMPairment:OPTimization:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:IMPairment:OPTimization:STATe \n
		Snippet: driver.source.bb.impairment.optimization.set_state(state = False) \n
		No command help available \n
			:param state: No help available
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:IMPairment:OPTimization:STATe {param}')



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PositionCls:
	"""Position commands group definition. 3 total commands, 0 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("position", core, parent)

	def get_ecef(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:UMOTion:[CSV]:POSition:ECEF \n
		Snippet: value: bool = driver.source.bb.gnss.logging.category.umotion.csv.position.get_ecef() \n
		Enables the parameter for logging. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:UMOTion:CSV:POSition:ECEF?')
		return Conversions.str_to_bool(response)

	def set_ecef(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:UMOTion:[CSV]:POSition:ECEF \n
		Snippet: driver.source.bb.gnss.logging.category.umotion.csv.position.set_ecef(state = False) \n
		Enables the parameter for logging. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:UMOTion:CSV:POSition:ECEF {param}')

	def get_enu(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:UMOTion:[CSV]:POSition:ENU \n
		Snippet: value: bool = driver.source.bb.gnss.logging.category.umotion.csv.position.get_enu() \n
		Enables the parameter for logging. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:UMOTion:CSV:POSition:ENU?')
		return Conversions.str_to_bool(response)

	def set_enu(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:UMOTion:[CSV]:POSition:ENU \n
		Snippet: driver.source.bb.gnss.logging.category.umotion.csv.position.set_enu(state = False) \n
		Enables the parameter for logging. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:UMOTion:CSV:POSition:ENU {param}')

	def get_lla(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:UMOTion:[CSV]:POSition:LLA \n
		Snippet: value: bool = driver.source.bb.gnss.logging.category.umotion.csv.position.get_lla() \n
		Enables the parameter for logging. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:UMOTion:CSV:POSition:LLA?')
		return Conversions.str_to_bool(response)

	def set_lla(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:UMOTion:[CSV]:POSition:LLA \n
		Snippet: driver.source.bb.gnss.logging.category.umotion.csv.position.set_lla(state = False) \n
		Enables the parameter for logging. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:UMOTion:CSV:POSition:LLA {param}')



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TrainCls:
	"""Train commands group definition. 30 total commands, 5 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("train", core, parent)

	@property
	def dexchange(self):
		"""dexchange commands group. 2 Sub-classes, 2 commands."""
		if not hasattr(self, '_dexchange'):
			from .Dexchange import DexchangeCls
			self._dexchange = DexchangeCls(self._core, self._cmd_group)
		return self._dexchange

	@property
	def hopping(self):
		"""hopping commands group. 5 Sub-classes, 3 commands."""
		if not hasattr(self, '_hopping'):
			from .Hopping import HoppingCls
			self._hopping = HoppingCls(self._core, self._cmd_group)
		return self._hopping

	@property
	def offTime(self):
		"""offTime commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_offTime'):
			from .OffTime import OffTimeCls
			self._offTime = OffTimeCls(self._core, self._cmd_group)
		return self._offTime

	@property
	def ontime(self):
		"""ontime commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_ontime'):
			from .Ontime import OntimeCls
			self._ontime = OntimeCls(self._core, self._cmd_group)
		return self._ontime

	@property
	def repetition(self):
		"""repetition commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_repetition'):
			from .Repetition import RepetitionCls
			self._repetition = RepetitionCls(self._core, self._cmd_group)
		return self._repetition

	def get_catalog(self) -> List[str]:
		"""SCPI: [SOURce<HW>]:PULM:TRAin:CATalog \n
		Snippet: value: List[str] = driver.source.pulm.train.get_catalog() \n
		Queries the available pulse train files in the specified directory. \n
			:return: catalog: string List of list filenames, separated by commas
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:PULM:TRAin:CATalog?')
		return Conversions.str_to_str_list(response)

	def delete(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:PULM:TRAin:DELete \n
		Snippet: driver.source.pulm.train.delete(filename = 'abc') \n
		Deletes the specified pulse train file. Refer to 'Accessing files in the default or in a specified directory' for general
		information on file handling in the default and in a specific directory. \n
			:param filename: string Filename or complete file path; file extension is optional.
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:PULM:TRAin:DELete {param}')

	def get_select(self) -> str:
		"""SCPI: [SOURce<HW>]:PULM:TRAin:SELect \n
		Snippet: value: str = driver.source.pulm.train.get_select() \n
		Selects or creates a data list in pulse train mode. If the list with the selected name does not exist, a new list is
		created. \n
			:return: filename: string Filename or complete file path; file extension can be omitted.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:PULM:TRAin:SELect?')
		return trim_str_response(response)

	def set_select(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:PULM:TRAin:SELect \n
		Snippet: driver.source.pulm.train.set_select(filename = 'abc') \n
		Selects or creates a data list in pulse train mode. If the list with the selected name does not exist, a new list is
		created. \n
			:param filename: string Filename or complete file path; file extension can be omitted.
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:PULM:TRAin:SELect {param}')

	def clone(self) -> 'TrainCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = TrainCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PredefinedCls:
	"""Predefined commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("predefined", core, parent)

	def set(self, predefined_env: enums.ObscModelFullObsc, vehicle=repcap.Vehicle.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RECeiver:[V<ST>]:ENVironment:FULL:PREDefined \n
		Snippet: driver.source.bb.gnss.receiver.v.environment.full.predefined.set(predefined_env = enums.ObscModelFullObsc.BR1, vehicle = repcap.Vehicle.Default) \n
		Loads a predefined environment configuration. You can load a user-defined setting or a predefined settings that simulate
		two urban canyon environments. \n
			:param predefined_env: USER| URB1| URB2 USER User-defined environment configuration URB1|URB2 Urban canyon environment configuration
			:param vehicle: optional repeated capability selector. Default value: Nr1 (settable in the interface 'V')
		"""
		param = Conversions.enum_scalar_to_str(predefined_env, enums.ObscModelFullObsc)
		vehicle_cmd_val = self._cmd_group.get_repcap_cmd_value(vehicle, repcap.Vehicle)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:RECeiver:V{vehicle_cmd_val}:ENVironment:FULL:PREDefined {param}')

	# noinspection PyTypeChecker
	def get(self, vehicle=repcap.Vehicle.Default) -> enums.ObscModelFullObsc:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RECeiver:[V<ST>]:ENVironment:FULL:PREDefined \n
		Snippet: value: enums.ObscModelFullObsc = driver.source.bb.gnss.receiver.v.environment.full.predefined.get(vehicle = repcap.Vehicle.Default) \n
		Loads a predefined environment configuration. You can load a user-defined setting or a predefined settings that simulate
		two urban canyon environments. \n
			:param vehicle: optional repeated capability selector. Default value: Nr1 (settable in the interface 'V')
			:return: predefined_env: USER| URB1| URB2 USER User-defined environment configuration URB1|URB2 Urban canyon environment configuration"""
		vehicle_cmd_val = self._cmd_group.get_repcap_cmd_value(vehicle, repcap.Vehicle)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:RECeiver:V{vehicle_cmd_val}:ENVironment:FULL:PREDefined?')
		return Conversions.str_to_scalar_enum(response, enums.ObscModelFullObsc)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LatencyCls:
	"""Latency commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("latency", core, parent)

	@property
	def statistics(self):
		"""statistics commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_statistics'):
			from .Statistics import StatisticsCls
			self._statistics = StatisticsCls(self._core, self._cmd_group)
		return self._statistics

	def get(self, vehicle=repcap.Vehicle.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RT:RECeiver:[V<ST>]:HILPosition:LATency \n
		Snippet: value: float = driver.source.bb.gnss.rt.receiver.v.hilPosition.latency.get(vehicle = repcap.Vehicle.Default) \n
		Queries the predicted latency that is the time delay between the elapsed time of HIL mode command and the time to execute
		this command in the R&S SMBV100B.
		HIL command refers to HiL mode A or HiL mode B commands: [:SOURce<hw>]:BB:GNSS:RT:RECeiver[:V<st>]:HILPosition:MODE:A
		[:SOURce<hw>]:BB:GNSS:RT:RECeiver[:V<st>]:HILPosition:MODE:B How to: 'Latency calibration' \n
			:param vehicle: optional repeated capability selector. Default value: Nr1 (settable in the interface 'V')
			:return: latency: float Range: min to max, Unit: s"""
		vehicle_cmd_val = self._cmd_group.get_repcap_cmd_value(vehicle, repcap.Vehicle)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:RT:RECeiver:V{vehicle_cmd_val}:HILPosition:LATency?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'LatencyCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = LatencyCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.RepeatedCapability import RepeatedCapability
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SvidCls:
	"""Svid commands group definition. 1363 total commands, 7 Subgroups, 0 group commands
	Repeated Capability: SatelliteSvid, default value after init: SatelliteSvid.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("svid", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_satelliteSvid_get', 'repcap_satelliteSvid_set', repcap.SatelliteSvid.Nr1)

	def repcap_satelliteSvid_set(self, satelliteSvid: repcap.SatelliteSvid) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to SatelliteSvid.Default
		Default value after init: SatelliteSvid.Nr1"""
		self._cmd_group.set_repcap_enum_value(satelliteSvid)

	def repcap_satelliteSvid_get(self) -> repcap.SatelliteSvid:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def beidou(self):
		"""beidou commands group. 13 Sub-classes, 0 commands."""
		if not hasattr(self, '_beidou'):
			from .Beidou import BeidouCls
			self._beidou = BeidouCls(self._core, self._cmd_group)
		return self._beidou

	@property
	def galileo(self):
		"""galileo commands group. 13 Sub-classes, 0 commands."""
		if not hasattr(self, '_galileo'):
			from .Galileo import GalileoCls
			self._galileo = GalileoCls(self._core, self._cmd_group)
		return self._galileo

	@property
	def glonass(self):
		"""glonass commands group. 14 Sub-classes, 0 commands."""
		if not hasattr(self, '_glonass'):
			from .Glonass import GlonassCls
			self._glonass = GlonassCls(self._core, self._cmd_group)
		return self._glonass

	@property
	def gps(self):
		"""gps commands group. 13 Sub-classes, 0 commands."""
		if not hasattr(self, '_gps'):
			from .Gps import GpsCls
			self._gps = GpsCls(self._core, self._cmd_group)
		return self._gps

	@property
	def navic(self):
		"""navic commands group. 13 Sub-classes, 0 commands."""
		if not hasattr(self, '_navic'):
			from .Navic import NavicCls
			self._navic = NavicCls(self._core, self._cmd_group)
		return self._navic

	@property
	def qzss(self):
		"""qzss commands group. 13 Sub-classes, 0 commands."""
		if not hasattr(self, '_qzss'):
			from .Qzss import QzssCls
			self._qzss = QzssCls(self._core, self._cmd_group)
		return self._qzss

	@property
	def sbas(self):
		"""sbas commands group. 14 Sub-classes, 0 commands."""
		if not hasattr(self, '_sbas'):
			from .Sbas import SbasCls
			self._sbas = SbasCls(self._core, self._cmd_group)
		return self._sbas

	def clone(self) -> 'SvidCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SvidCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Types import DataType
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct
from .......Internal.ArgSingleList import ArgSingleList
from .......Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AcAssignedCls:
	"""AcAssigned commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("acAssigned", core, parent)

	def set(self, ac_assigned: str, bitcount: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:PCONfiguration:ACASsigned \n
		Snippet: driver.source.bb.btooth.econfiguration.pconfiguration.acAssigned.set(ac_assigned = rawAbc, bitcount = 1) \n
		Sets the advertiser's device address. For advertising channel packets, the format of the device address differs,
		depending on the selected address type.
			INTRO_CMD_HELP: Selects the clock source: \n
			- 'Public Address Types' The public address is given from the registration authority IEEE and is composed of:
			Table Header:  \n
			- LSB: 24 bits = company_assigned
			- MSB: 24 bits = company_id
			- 'Random Address Type' is a 48-bits random static device address.
			- 'Private Address Type' A private address is optional and composed of:
			Table Header:  \n
			- LSB: 24 bits = hash
			- MSB: 24 bits = random \n
			:param ac_assigned: numeric
			:param bitcount: integer Range: 24 to 24
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('ac_assigned', ac_assigned, DataType.RawString), ArgSingle('bitcount', bitcount, DataType.Integer))
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:ECONfiguration:PCONfiguration:ACASsigned {param}'.rstrip())

	# noinspection PyTypeChecker
	class AcAssignedStruct(StructBase):
		"""Response structure. Fields: \n
			- Ac_Assigned: str: No parameter help available
			- Bitcount: int: integer Range: 24 to 24"""
		__meta_args_list = [
			ArgStruct.scalar_raw_str('Ac_Assigned'),
			ArgStruct.scalar_int('Bitcount')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Ac_Assigned: str = None
			self.Bitcount: int = None

	def get(self) -> AcAssignedStruct:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:PCONfiguration:ACASsigned \n
		Snippet: value: AcAssignedStruct = driver.source.bb.btooth.econfiguration.pconfiguration.acAssigned.get() \n
		Sets the advertiser's device address. For advertising channel packets, the format of the device address differs,
		depending on the selected address type.
			INTRO_CMD_HELP: Selects the clock source: \n
			- 'Public Address Types' The public address is given from the registration authority IEEE and is composed of:
			Table Header:  \n
			- LSB: 24 bits = company_assigned
			- MSB: 24 bits = company_id
			- 'Random Address Type' is a 48-bits random static device address.
			- 'Private Address Type' A private address is optional and composed of:
			Table Header:  \n
			- LSB: 24 bits = hash
			- MSB: 24 bits = random \n
			:return: structure: for return value, see the help for AcAssignedStruct structure arguments."""
		return self._core.io.query_struct(f'SOURce<HwInstance>:BB:BTOoth:ECONfiguration:PCONfiguration:ACASsigned?', self.__class__.AcAssignedStruct())



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PowerCls:
	"""Power commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("power", core, parent)

	def get_reference(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:GNSS:POWer:REFerence \n
		Snippet: value: float = driver.source.bb.gnss.power.get_reference() \n
		Sets the power level that is used as a reference for the calculation of the power level of the satellites. \n
			:return: reference_power: float Range: -145 to 20
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:POWer:REFerence?')
		return Conversions.str_to_float(response)

	def set_reference(self, reference_power: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:POWer:REFerence \n
		Snippet: driver.source.bb.gnss.power.set_reference(reference_power = 1.0) \n
		Sets the power level that is used as a reference for the calculation of the power level of the satellites. \n
			:param reference_power: float Range: -145 to 20
		"""
		param = Conversions.decimal_value_to_str(reference_power)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:POWer:REFerence {param}')



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NzConfigCls:
	"""NzConfig commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("nzConfig", core, parent)

	def set(self, non_zero_pwr_conf: enums.NumbersE, cellNull=repcap.CellNull.Default, csiRefSignal=repcap.CsiRefSignal.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:DRS:CELL<CH0>:CSIRs<ST>:NZConfig \n
		Snippet: driver.source.bb.eutra.downlink.drs.cell.csirs.nzConfig.set(non_zero_pwr_conf = enums.NumbersE._0, cellNull = repcap.CellNull.Default, csiRefSignal = repcap.CsiRefSignal.Default) \n
		Sets the CSI-RS configuration. \n
			:param non_zero_pwr_conf: 0| 1| 2| 3| 4| 5| 6| 7| 8| 9| 10| 11| 12| 13| 14| 15| 16| 17| 18| 19| 20| 21| 22| 23| 24| 25| 26| 27| 28| 29| 30| 31 Values outside the permitted discrete values are rounded down.
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param csiRefSignal: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Csirs')
		"""
		param = Conversions.enum_scalar_to_str(non_zero_pwr_conf, enums.NumbersE)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		csiRefSignal_cmd_val = self._cmd_group.get_repcap_cmd_value(csiRefSignal, repcap.CsiRefSignal)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:DRS:CELL{cellNull_cmd_val}:CSIRs{csiRefSignal_cmd_val}:NZConfig {param}')

	# noinspection PyTypeChecker
	def get(self, cellNull=repcap.CellNull.Default, csiRefSignal=repcap.CsiRefSignal.Default) -> enums.NumbersE:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:DRS:CELL<CH0>:CSIRs<ST>:NZConfig \n
		Snippet: value: enums.NumbersE = driver.source.bb.eutra.downlink.drs.cell.csirs.nzConfig.get(cellNull = repcap.CellNull.Default, csiRefSignal = repcap.CsiRefSignal.Default) \n
		Sets the CSI-RS configuration. \n
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param csiRefSignal: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Csirs')
			:return: non_zero_pwr_conf: 0| 1| 2| 3| 4| 5| 6| 7| 8| 9| 10| 11| 12| 13| 14| 15| 16| 17| 18| 19| 20| 21| 22| 23| 24| 25| 26| 27| 28| 29| 30| 31 Values outside the permitted discrete values are rounded down."""
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		csiRefSignal_cmd_val = self._cmd_group.get_repcap_cmd_value(csiRefSignal, repcap.CsiRefSignal)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:DRS:CELL{cellNull_cmd_val}:CSIRs{csiRefSignal_cmd_val}:NZConfig?')
		return Conversions.str_to_scalar_enum(response, enums.NumbersE)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IqswapCls:
	"""Iqswap commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("iqswap", core, parent)

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:C2K:IQSWap:[STATe] \n
		Snippet: value: bool = driver.source.bb.c2K.iqswap.get_state() \n
		This command inverts the Q-part of the baseband signal if set to ON. The signal on the baseband outputs meets the
		cdma2000 standard. In order to generate an RF signal that conforms to the standard, the 'I/Q Swap' function in the 'I/Q
		Modulator' menu must be enabled ('On') (SOURce:IQ:SWAP ON) . \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:C2K:IQSWap:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:C2K:IQSWap:[STATe] \n
		Snippet: driver.source.bb.c2K.iqswap.set_state(state = False) \n
		This command inverts the Q-part of the baseband signal if set to ON. The signal on the baseband outputs meets the
		cdma2000 standard. In order to generate an RF signal that conforms to the standard, the 'I/Q Swap' function in the 'I/Q
		Modulator' menu must be enabled ('On') (SOURce:IQ:SWAP ON) . \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:C2K:IQSWap:STATe {param}')



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.Types import DataType
from ........Internal.StructBase import StructBase
from ........Internal.ArgStruct import ArgStruct
from ........Internal.ArgSingleList import ArgSingleList
from ........Internal.ArgSingle import ArgSingle
from ........Internal.RepeatedCapability import RepeatedCapability
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PortCls:
	"""Port commands group definition. 1 total commands, 0 Subgroups, 1 group commands
	Repeated Capability: PortNull, default value after init: PortNull.Nr0"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("port", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_portNull_get', 'repcap_portNull_set', repcap.PortNull.Nr0)

	def repcap_portNull_set(self, portNull: repcap.PortNull) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to PortNull.Default
		Default value after init: PortNull.Nr0"""
		self._cmd_group.set_repcap_enum_value(portNull)

	def repcap_portNull_get(self) -> repcap.PortNull:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	def set(self, pattern: str, bitcount: int, portNull=repcap.PortNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:WS:CQIPattern:PORT<CH0> \n
		Snippet: driver.source.bb.eutra.tcw.ws.cqiPattern.port.set(pattern = rawAbc, bitcount = 1, portNull = repcap.PortNull.Default) \n
		No command help available \n
			:param pattern: No help available
			:param bitcount: No help available
			:param portNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Port')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('pattern', pattern, DataType.RawString), ArgSingle('bitcount', bitcount, DataType.Integer))
		portNull_cmd_val = self._cmd_group.get_repcap_cmd_value(portNull, repcap.PortNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:TCW:WS:CQIPattern:PORT{portNull_cmd_val} {param}'.rstrip())

	# noinspection PyTypeChecker
	class PortStruct(StructBase):
		"""Response structure. Fields: \n
			- Pattern: str: No parameter help available
			- Bitcount: int: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_raw_str('Pattern'),
			ArgStruct.scalar_int('Bitcount')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Pattern: str = None
			self.Bitcount: int = None

	def get(self, portNull=repcap.PortNull.Default) -> PortStruct:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:WS:CQIPattern:PORT<CH0> \n
		Snippet: value: PortStruct = driver.source.bb.eutra.tcw.ws.cqiPattern.port.get(portNull = repcap.PortNull.Default) \n
		No command help available \n
			:param portNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Port')
			:return: structure: for return value, see the help for PortStruct structure arguments."""
		portNull_cmd_val = self._cmd_group.get_repcap_cmd_value(portNull, repcap.PortNull)
		return self._core.io.query_struct(f'SOURce<HwInstance>:BB:EUTRa:TCW:WS:CQIPattern:PORT{portNull_cmd_val}?', self.__class__.PortStruct())

	def clone(self) -> 'PortCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PortCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .............Internal.Core import Core
from .............Internal.CommandsGroup import CommandsGroup
from .............Internal import Conversions
from .............Internal.RepeatedCapability import RepeatedCapability
from ............. import enums
from ............. import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ApSelectCls:
	"""ApSelect commands group definition. 1 total commands, 0 Subgroups, 1 group commands
	Repeated Capability: AntennaPortNull, default value after init: AntennaPortNull.Nr0"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("apSelect", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_antennaPortNull_get', 'repcap_antennaPortNull_set', repcap.AntennaPortNull.Nr0)

	def repcap_antennaPortNull_set(self, antennaPortNull: repcap.AntennaPortNull) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to AntennaPortNull.Default
		Default value after init: AntennaPortNull.Nr0"""
		self._cmd_group.set_repcap_enum_value(antennaPortNull)

	def repcap_antennaPortNull_get(self) -> repcap.AntennaPortNull:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	def set(self, pdsch_ap_sel: enums.Nr5GpdschAp, cellNull=repcap.CellNull.Default, subframeNull=repcap.SubframeNull.Default, userNull=repcap.UserNull.Default, bwPartNull=repcap.BwPartNull.Default, allocationNull=repcap.AllocationNull.Default, antennaPortNull=repcap.AntennaPortNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:SCHed:CELL<CC(CH0)>:SUBF<SF(ST0)>:USER<US(DIR0)>:BWPart<BWP(GR0)>:ALLoc<AL(USER0)>:PDSCh:[DMRS]:APSelect<S2US0> \n
		Snippet: driver.source.bb.nr5G.scheduling.cell.subf.user.bwPart.alloc.pdsch.dmrs.apSelect.set(pdsch_ap_sel = enums.Nr5GpdschAp.AP1000, cellNull = repcap.CellNull.Default, subframeNull = repcap.SubframeNull.Default, userNull = repcap.UserNull.Default, bwPartNull = repcap.BwPartNull.Default, allocationNull = repcap.AllocationNull.Default, antennaPortNull = repcap.AntennaPortNull.Default) \n
		Each layer of a PDSCH allocation is mapped to a certain antenna port. By the command the antenna ports are selected which
		are used for the transmission of the PDSCH allocation. \n
			:param pdsch_ap_sel: AP1000| AP1001| AP1002| AP1003| AP1004| AP1005| AP1006| AP1007| AP1008| AP1009| AP1010| AP1011
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'BwPart')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:param antennaPortNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'ApSelect')
		"""
		param = Conversions.enum_scalar_to_str(pdsch_ap_sel, enums.Nr5GpdschAp)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		subframeNull_cmd_val = self._cmd_group.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		bwPartNull_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		allocationNull_cmd_val = self._cmd_group.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		antennaPortNull_cmd_val = self._cmd_group.get_repcap_cmd_value(antennaPortNull, repcap.AntennaPortNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:SCHed:CELL{cellNull_cmd_val}:SUBF{subframeNull_cmd_val}:USER{userNull_cmd_val}:BWPart{bwPartNull_cmd_val}:ALLoc{allocationNull_cmd_val}:PDSCh:DMRS:APSelect{antennaPortNull_cmd_val} {param}')

	# noinspection PyTypeChecker
	def get(self, cellNull=repcap.CellNull.Default, subframeNull=repcap.SubframeNull.Default, userNull=repcap.UserNull.Default, bwPartNull=repcap.BwPartNull.Default, allocationNull=repcap.AllocationNull.Default, antennaPortNull=repcap.AntennaPortNull.Default) -> enums.Nr5GpdschAp:
		"""SCPI: [SOURce<HW>]:BB:NR5G:SCHed:CELL<CC(CH0)>:SUBF<SF(ST0)>:USER<US(DIR0)>:BWPart<BWP(GR0)>:ALLoc<AL(USER0)>:PDSCh:[DMRS]:APSelect<S2US0> \n
		Snippet: value: enums.Nr5GpdschAp = driver.source.bb.nr5G.scheduling.cell.subf.user.bwPart.alloc.pdsch.dmrs.apSelect.get(cellNull = repcap.CellNull.Default, subframeNull = repcap.SubframeNull.Default, userNull = repcap.UserNull.Default, bwPartNull = repcap.BwPartNull.Default, allocationNull = repcap.AllocationNull.Default, antennaPortNull = repcap.AntennaPortNull.Default) \n
		Each layer of a PDSCH allocation is mapped to a certain antenna port. By the command the antenna ports are selected which
		are used for the transmission of the PDSCH allocation. \n
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'BwPart')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:param antennaPortNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'ApSelect')
			:return: pdsch_ap_sel: AP1000| AP1001| AP1002| AP1003| AP1004| AP1005| AP1006| AP1007| AP1008| AP1009| AP1010| AP1011"""
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		subframeNull_cmd_val = self._cmd_group.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		bwPartNull_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		allocationNull_cmd_val = self._cmd_group.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		antennaPortNull_cmd_val = self._cmd_group.get_repcap_cmd_value(antennaPortNull, repcap.AntennaPortNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:SCHed:CELL{cellNull_cmd_val}:SUBF{subframeNull_cmd_val}:USER{userNull_cmd_val}:BWPart{bwPartNull_cmd_val}:ALLoc{allocationNull_cmd_val}:PDSCh:DMRS:APSelect{antennaPortNull_cmd_val}?')
		return Conversions.str_to_scalar_enum(response, enums.Nr5GpdschAp)

	def clone(self) -> 'ApSelectCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ApSelectCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UseCls:
	"""Use commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("use", core, parent)

	def set(self, use: bool, frameIx=repcap.FrameIx.Default, slotNull=repcap.SlotNull.Default, subchannel=repcap.Subchannel.Default, userIx=repcap.UserIx.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GSM:[FRAMe<DI>]:SLOT<ST0>:[SUBChannel<US>]:[USER<CH>]:SFLag:USE \n
		Snippet: driver.source.bb.gsm.frame.slot.subChannel.user.sflag.use.set(use = False, frameIx = repcap.FrameIx.Default, slotNull = repcap.SlotNull.Default, subchannel = repcap.Subchannel.Default, userIx = repcap.UserIx.Default) \n
		The command enables or disables the use of Stealing Flags. If not used, the Stealing Flags bits are allocated to the DATA
		fields (only for Normal burst BB:GSM:SLOT:TYPE NORM) . \n
			:param use: 1| ON| 0| OFF
			:param frameIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
			:param slotNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Slot')
			:param subchannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'SubChannel')
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
		"""
		param = Conversions.bool_to_str(use)
		frameIx_cmd_val = self._cmd_group.get_repcap_cmd_value(frameIx, repcap.FrameIx)
		slotNull_cmd_val = self._cmd_group.get_repcap_cmd_value(slotNull, repcap.SlotNull)
		subchannel_cmd_val = self._cmd_group.get_repcap_cmd_value(subchannel, repcap.Subchannel)
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		self._core.io.write(f'SOURce<HwInstance>:BB:GSM:FRAMe{frameIx_cmd_val}:SLOT{slotNull_cmd_val}:SUBChannel{subchannel_cmd_val}:USER{userIx_cmd_val}:SFLag:USE {param}')

	def get(self, frameIx=repcap.FrameIx.Default, slotNull=repcap.SlotNull.Default, subchannel=repcap.Subchannel.Default, userIx=repcap.UserIx.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GSM:[FRAMe<DI>]:SLOT<ST0>:[SUBChannel<US>]:[USER<CH>]:SFLag:USE \n
		Snippet: value: bool = driver.source.bb.gsm.frame.slot.subChannel.user.sflag.use.get(frameIx = repcap.FrameIx.Default, slotNull = repcap.SlotNull.Default, subchannel = repcap.Subchannel.Default, userIx = repcap.UserIx.Default) \n
		The command enables or disables the use of Stealing Flags. If not used, the Stealing Flags bits are allocated to the DATA
		fields (only for Normal burst BB:GSM:SLOT:TYPE NORM) . \n
			:param frameIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
			:param slotNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Slot')
			:param subchannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'SubChannel')
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:return: use: 1| ON| 0| OFF"""
		frameIx_cmd_val = self._cmd_group.get_repcap_cmd_value(frameIx, repcap.FrameIx)
		slotNull_cmd_val = self._cmd_group.get_repcap_cmd_value(slotNull, repcap.SlotNull)
		subchannel_cmd_val = self._cmd_group.get_repcap_cmd_value(subchannel, repcap.Subchannel)
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GSM:FRAMe{frameIx_cmd_val}:SLOT{slotNull_cmd_val}:SUBChannel{subchannel_cmd_val}:USER{userIx_cmd_val}:SFLag:USE?')
		return Conversions.str_to_bool(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DeviceCls:
	"""Device commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("device", core, parent)

	def get_id(self) -> str:
		"""SCPI: [SOURce<HW>]:AREGenerator:EXTernal:REMote:EDIT:DEVice:[ID] \n
		Snippet: value: str = driver.source.areGenerator.external.remote.edit.device.get_id() \n
		No command help available \n
			:return: device_id: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:EXTernal:REMote:EDIT:DEVice:ID?')
		return trim_str_response(response)

	def set_id(self, device_id: str) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:EXTernal:REMote:EDIT:DEVice:[ID] \n
		Snippet: driver.source.areGenerator.external.remote.edit.device.set_id(device_id = 'abc') \n
		No command help available \n
			:param device_id: No help available
		"""
		param = Conversions.value_to_quoted_str(device_id)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:EXTernal:REMote:EDIT:DEVice:ID {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ExternalCls:
	"""External commands group definition. 6 total commands, 2 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("external", core, parent)

	@property
	def frequency(self):
		"""frequency commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_frequency'):
			from .Frequency import FrequencyCls
			self._frequency = FrequencyCls(self._core, self._cmd_group)
		return self._frequency

	@property
	def rfOff(self):
		"""rfOff commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rfOff'):
			from .RfOff import RfOffCls
			self._rfOff = RfOffCls(self._core, self._cmd_group)
		return self._rfOff

	def get_mlrange(self) -> str:
		"""SCPI: [SOURce]:ROSCillator:EXTernal:MLRange \n
		Snippet: value: str = driver.source.roscillator.external.get_mlrange() \n
		Queries the minimum locking range for the selected external reference frequency. Depending on the RF hardware version,
		and the installed options, the minimum locking range vaies. For more information, see data sheet. \n
			:return: min_lock_range: string
		"""
		response = self._core.io.query_str('SOURce:ROSCillator:EXTernal:MLRange?')
		return trim_str_response(response)

	def get_ns_bandwidth(self) -> str:
		"""SCPI: [SOURce]:ROSCillator:EXTernal:NSBandwidth \n
		Snippet: value: str = driver.source.roscillator.external.get_ns_bandwidth() \n
		Queries the nominal synchronization bandwidth for the selected external reference frequency and synchronization bandwidth. \n
			:return: nom_bandwidth: string
		"""
		response = self._core.io.query_str('SOURce:ROSCillator:EXTernal:NSBandwidth?')
		return trim_str_response(response)

	# noinspection PyTypeChecker
	def get_sbandwidth(self) -> enums.FilterWidth:
		"""SCPI: [SOURce]:ROSCillator:EXTernal:SBANdwidth \n
		Snippet: value: enums.FilterWidth = driver.source.roscillator.external.get_sbandwidth() \n
		Selects the synchronization bandwidth for the external reference signal. See [:SOURce]:ROSCillator:SOURce > External.
		Depending on the RF hardware version, and the installed options, the synchronization bandwidth varies.
		For more information, see data sheet. \n
			:return: sbandwidth: WIDE| NARRow NARRow The synchronization bandwidth is a few Hz. WIDE Uses the widest possible synchronization bandwidth.
		"""
		response = self._core.io.query_str('SOURce:ROSCillator:EXTernal:SBANdwidth?')
		return Conversions.str_to_scalar_enum(response, enums.FilterWidth)

	def set_sbandwidth(self, sbandwidth: enums.FilterWidth) -> None:
		"""SCPI: [SOURce]:ROSCillator:EXTernal:SBANdwidth \n
		Snippet: driver.source.roscillator.external.set_sbandwidth(sbandwidth = enums.FilterWidth.NARRow) \n
		Selects the synchronization bandwidth for the external reference signal. See [:SOURce]:ROSCillator:SOURce > External.
		Depending on the RF hardware version, and the installed options, the synchronization bandwidth varies.
		For more information, see data sheet. \n
			:param sbandwidth: WIDE| NARRow NARRow The synchronization bandwidth is a few Hz. WIDE Uses the widest possible synchronization bandwidth.
		"""
		param = Conversions.enum_scalar_to_str(sbandwidth, enums.FilterWidth)
		self._core.io.write(f'SOURce:ROSCillator:EXTernal:SBANdwidth {param}')

	def clone(self) -> 'ExternalCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ExternalCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.Types import DataType
from ........Internal.StructBase import StructBase
from ........Internal.ArgStruct import ArgStruct
from ........Internal.ArgSingleList import ArgSingleList
from ........Internal.ArgSingle import ArgSingle
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PatternCls:
	"""Pattern commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pattern", core, parent)

	def set(self, pattern: str, bitcount: int, mobileStation=repcap.MobileStation.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation<ST>:DPCCh:FBI:PATTern \n
		Snippet: driver.source.bb.w3Gpp.mstation.dpcch.fbi.pattern.set(pattern = rawAbc, bitcount = 1, mobileStation = repcap.MobileStation.Default) \n
		The command determines the bit pattern when the PATTern data source is selected for the FBI field. \n
			:param pattern: numeric The first parameter determines the bit pattern (choice of hexadecimal, octal or binary notation) , the second specifies the number of bits to use.
			:param bitcount: integer Range: 1 to 32
			:param mobileStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mstation')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('pattern', pattern, DataType.RawString), ArgSingle('bitcount', bitcount, DataType.Integer))
		mobileStation_cmd_val = self._cmd_group.get_repcap_cmd_value(mobileStation, repcap.MobileStation)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:MSTation{mobileStation_cmd_val}:DPCCh:FBI:PATTern {param}'.rstrip())

	# noinspection PyTypeChecker
	class PatternStruct(StructBase):
		"""Response structure. Fields: \n
			- Pattern: str: numeric The first parameter determines the bit pattern (choice of hexadecimal, octal or binary notation) , the second specifies the number of bits to use.
			- Bitcount: int: integer Range: 1 to 32"""
		__meta_args_list = [
			ArgStruct.scalar_raw_str('Pattern'),
			ArgStruct.scalar_int('Bitcount')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Pattern: str = None
			self.Bitcount: int = None

	def get(self, mobileStation=repcap.MobileStation.Default) -> PatternStruct:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation<ST>:DPCCh:FBI:PATTern \n
		Snippet: value: PatternStruct = driver.source.bb.w3Gpp.mstation.dpcch.fbi.pattern.get(mobileStation = repcap.MobileStation.Default) \n
		The command determines the bit pattern when the PATTern data source is selected for the FBI field. \n
			:param mobileStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mstation')
			:return: structure: for return value, see the help for PatternStruct structure arguments."""
		mobileStation_cmd_val = self._cmd_group.get_repcap_cmd_value(mobileStation, repcap.MobileStation)
		return self._core.io.query_struct(f'SOURce<HwInstance>:BB:W3GPp:MSTation{mobileStation_cmd_val}:DPCCh:FBI:PATTern?', self.__class__.PatternStruct())



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SformatCls:
	"""Sformat commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sformat", core, parent)

	def set(self, sformat: int, baseStation=repcap.BaseStation.Default, channelNull=repcap.ChannelNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation<ST>:CHANnel<CH0>:SFORmat \n
		Snippet: driver.source.bb.w3Gpp.bstation.channel.sformat.set(sformat = 1, baseStation = repcap.BaseStation.Default, channelNull = repcap.ChannelNull.Default) \n
		The command sets the slot format of the selected channel. The value range depends on the selected channel.
		The slot format determines the symbol rate (and thus the range of values for the channelization code) , the TFCI state
		and the pilot length. If the value of any one of the four parameters is changed, all the other parameters are adapted as
		necessary. In the case of enhanced channels with active channel coding, the selected channel coding also affects the slot
		format and thus the remaining parameters. If these parameters are changed, the channel coding type is set to user. \n
			:param sformat: integer Range: 0 to dynamic
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')
		"""
		param = Conversions.decimal_value_to_str(sformat)
		baseStation_cmd_val = self._cmd_group.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		channelNull_cmd_val = self._cmd_group.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:BSTation{baseStation_cmd_val}:CHANnel{channelNull_cmd_val}:SFORmat {param}')

	def get(self, baseStation=repcap.BaseStation.Default, channelNull=repcap.ChannelNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation<ST>:CHANnel<CH0>:SFORmat \n
		Snippet: value: int = driver.source.bb.w3Gpp.bstation.channel.sformat.get(baseStation = repcap.BaseStation.Default, channelNull = repcap.ChannelNull.Default) \n
		The command sets the slot format of the selected channel. The value range depends on the selected channel.
		The slot format determines the symbol rate (and thus the range of values for the channelization code) , the TFCI state
		and the pilot length. If the value of any one of the four parameters is changed, all the other parameters are adapted as
		necessary. In the case of enhanced channels with active channel coding, the selected channel coding also affects the slot
		format and thus the remaining parameters. If these parameters are changed, the channel coding type is set to user. \n
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')
			:return: sformat: integer Range: 0 to dynamic"""
		baseStation_cmd_val = self._cmd_group.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		channelNull_cmd_val = self._cmd_group.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:BSTation{baseStation_cmd_val}:CHANnel{channelNull_cmd_val}:SFORmat?')
		return Conversions.str_to_int(response)



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal import Conversions
from ........... import enums
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LengthCls:
	"""Length commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("length", core, parent)

	def set(self, length: enums.TdscdmaTfciLen, cell=repcap.Cell.Default, slotNull=repcap.SlotNull.Default, channelNull=repcap.ChannelNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:DOWN:CELL<ST>:SLOT<CH0>:CHANnel<US0>:DPCCh:TFCI:LENGth \n
		Snippet: driver.source.bb.tdscdma.down.cell.slot.channel.dpcch.tfci.length.set(length = enums.TdscdmaTfciLen._0, cell = repcap.Cell.Default, slotNull = repcap.SlotNull.Default, channelNull = repcap.ChannelNull.Default) \n
		Sets the length of the TFCI field in bits. \n
			:param length: 0| 4| 6| 8| 12| 16| 24| 32| 48
			:param cell: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')
			:param slotNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Slot')
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')
		"""
		param = Conversions.enum_scalar_to_str(length, enums.TdscdmaTfciLen)
		cell_cmd_val = self._cmd_group.get_repcap_cmd_value(cell, repcap.Cell)
		slotNull_cmd_val = self._cmd_group.get_repcap_cmd_value(slotNull, repcap.SlotNull)
		channelNull_cmd_val = self._cmd_group.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:TDSCdma:DOWN:CELL{cell_cmd_val}:SLOT{slotNull_cmd_val}:CHANnel{channelNull_cmd_val}:DPCCh:TFCI:LENGth {param}')

	# noinspection PyTypeChecker
	def get(self, cell=repcap.Cell.Default, slotNull=repcap.SlotNull.Default, channelNull=repcap.ChannelNull.Default) -> enums.TdscdmaTfciLen:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:DOWN:CELL<ST>:SLOT<CH0>:CHANnel<US0>:DPCCh:TFCI:LENGth \n
		Snippet: value: enums.TdscdmaTfciLen = driver.source.bb.tdscdma.down.cell.slot.channel.dpcch.tfci.length.get(cell = repcap.Cell.Default, slotNull = repcap.SlotNull.Default, channelNull = repcap.ChannelNull.Default) \n
		Sets the length of the TFCI field in bits. \n
			:param cell: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')
			:param slotNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Slot')
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')
			:return: length: 0| 4| 6| 8| 12| 16| 24| 32| 48"""
		cell_cmd_val = self._cmd_group.get_repcap_cmd_value(cell, repcap.Cell)
		slotNull_cmd_val = self._cmd_group.get_repcap_cmd_value(slotNull, repcap.SlotNull)
		channelNull_cmd_val = self._cmd_group.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:TDSCdma:DOWN:CELL{cell_cmd_val}:SLOT{slotNull_cmd_val}:CHANnel{channelNull_cmd_val}:DPCCh:TFCI:LENGth?')
		return Conversions.str_to_scalar_enum(response, enums.TdscdmaTfciLen)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Csi2Cls:
	"""Csi2 commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("csi2", core, parent)

	def get_pattern(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:WS:UCI:CSI2:PATTern \n
		Snippet: value: str = driver.source.bb.nr5G.tcw.ws.uci.csi2.get_pattern() \n
		Defines the frequency and time domain of the CSI part 2 subcarrier location. \n
			:return: csi_2_pattern: Nr5gPUCCHUcidataPattLenMax bits
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:TCW:WS:UCI:CSI2:PATTern?')
		return trim_str_response(response)

	def set_pattern(self, csi_2_pattern: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:WS:UCI:CSI2:PATTern \n
		Snippet: driver.source.bb.nr5G.tcw.ws.uci.csi2.set_pattern(csi_2_pattern = rawAbc) \n
		Defines the frequency and time domain of the CSI part 2 subcarrier location. \n
			:param csi_2_pattern: Nr5gPUCCHUcidataPattLenMax bits
		"""
		param = Conversions.value_to_str(csi_2_pattern)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:TCW:WS:UCI:CSI2:PATTern {param}')



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class GsrCls:
	"""Gsr commands group definition. 11 total commands, 11 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("gsr", core, parent)

	@property
	def conductivity(self):
		"""conductivity commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_conductivity'):
			from .Conductivity import ConductivityCls
			self._conductivity = ConductivityCls(self._core, self._cmd_group)
		return self._conductivity

	@property
	def galtitude(self):
		"""galtitude commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_galtitude'):
			from .Galtitude import GaltitudeCls
			self._galtitude = GaltitudeCls(self._core, self._cmd_group)
		return self._galtitude

	@property
	def mproperty(self):
		"""mproperty commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mproperty'):
			from .Mproperty import MpropertyCls
			self._mproperty = MpropertyCls(self._core, self._cmd_group)
		return self._mproperty

	@property
	def o1Distance(self):
		"""o1Distance commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_o1Distance'):
			from .O1Distance import O1DistanceCls
			self._o1Distance = O1DistanceCls(self._core, self._cmd_group)
		return self._o1Distance

	@property
	def o1Height(self):
		"""o1Height commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_o1Height'):
			from .O1Height import O1HeightCls
			self._o1Height = O1HeightCls(self._core, self._cmd_group)
		return self._o1Height

	@property
	def o2Distance(self):
		"""o2Distance commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_o2Distance'):
			from .O2Distance import O2DistanceCls
			self._o2Distance = O2DistanceCls(self._core, self._cmd_group)
		return self._o2Distance

	@property
	def o2Height(self):
		"""o2Height commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_o2Height'):
			from .O2Height import O2HeightCls
			self._o2Height = O2HeightCls(self._core, self._cmd_group)
		return self._o2Height

	@property
	def oorientation(self):
		"""oorientation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_oorientation'):
			from .Oorientation import OorientationCls
			self._oorientation = OorientationCls(self._core, self._cmd_group)
		return self._oorientation

	@property
	def permittivity(self):
		"""permittivity commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_permittivity'):
			from .Permittivity import PermittivityCls
			self._permittivity = PermittivityCls(self._core, self._cmd_group)
		return self._permittivity

	@property
	def ploss(self):
		"""ploss commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ploss'):
			from .Ploss import PlossCls
			self._ploss = PlossCls(self._core, self._cmd_group)
		return self._ploss

	@property
	def stype(self):
		"""stype commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_stype'):
			from .Stype import StypeCls
			self._stype = StypeCls(self._core, self._cmd_group)
		return self._stype

	def clone(self) -> 'GsrCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = GsrCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MinimumCls:
	"""Minimum commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("minimum", core, parent)

	def set(self, minimum: enums.EvdoPayload, terminal=repcap.Terminal.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EVDO:TERMinal<ST>:APCHannel:PAYLoad:MINimum \n
		Snippet: driver.source.bb.evdo.terminal.apChannel.payload.minimum.set(minimum = enums.EvdoPayload.PS1024, terminal = repcap.Terminal.Default) \n
		(enabled for Physical Layer subtype 2 and for an access terminal working in traffic mode) Sets the minimum payload size
		in bits of the data channel that activates the transmission of the auxiliary pilot channel. \n
			:param minimum: PS128| PS256| PS512| PS768| PS1024| PS1536| PS2048| PS3072| PS4096| PS6144| PS8192| PS12288
			:param terminal: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Terminal')
		"""
		param = Conversions.enum_scalar_to_str(minimum, enums.EvdoPayload)
		terminal_cmd_val = self._cmd_group.get_repcap_cmd_value(terminal, repcap.Terminal)
		self._core.io.write(f'SOURce<HwInstance>:BB:EVDO:TERMinal{terminal_cmd_val}:APCHannel:PAYLoad:MINimum {param}')

	# noinspection PyTypeChecker
	def get(self, terminal=repcap.Terminal.Default) -> enums.EvdoPayload:
		"""SCPI: [SOURce<HW>]:BB:EVDO:TERMinal<ST>:APCHannel:PAYLoad:MINimum \n
		Snippet: value: enums.EvdoPayload = driver.source.bb.evdo.terminal.apChannel.payload.minimum.get(terminal = repcap.Terminal.Default) \n
		(enabled for Physical Layer subtype 2 and for an access terminal working in traffic mode) Sets the minimum payload size
		in bits of the data channel that activates the transmission of the auxiliary pilot channel. \n
			:param terminal: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Terminal')
			:return: minimum: PS128| PS256| PS512| PS768| PS1024| PS1536| PS2048| PS3072| PS4096| PS6144| PS8192| PS12288"""
		terminal_cmd_val = self._cmd_group.get_repcap_cmd_value(terminal, repcap.Terminal)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EVDO:TERMinal{terminal_cmd_val}:APCHannel:PAYLoad:MINimum?')
		return Conversions.str_to_scalar_enum(response, enums.EvdoPayload)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RfPhaseCls:
	"""RfPhase commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rfPhase", core, parent)

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.PcmOdeAll:
		"""SCPI: [SOURce<HW>]:BB:NR5G:NODE:RFPHase:MODE \n
		Snippet: value: enums.PcmOdeAll = driver.source.bb.nr5G.node.rfPhase.get_mode() \n
		Enables the frequency-related phase compensation after each symbol, as specified in . It uses the parameter 'Frequency in
		GHz' to set the carrier frequency to be compensated. \n
			:return: rf_phase_comp: 0| OFF| MANual| 1| AUTO 0|OFF Disables the frequency-related phase compensation. MANual Enables the 'Frequency in GHz' field for manual input of the carrier frequency value to be compensated. 1|AUTO Sets automatically the carrier 'Frequency in GHz' value to be compensated.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:NODE:RFPHase:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.PcmOdeAll)

	def set_mode(self, rf_phase_comp: enums.PcmOdeAll) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:NODE:RFPHase:MODE \n
		Snippet: driver.source.bb.nr5G.node.rfPhase.set_mode(rf_phase_comp = enums.PcmOdeAll._0) \n
		Enables the frequency-related phase compensation after each symbol, as specified in . It uses the parameter 'Frequency in
		GHz' to set the carrier frequency to be compensated. \n
			:param rf_phase_comp: 0| OFF| MANual| 1| AUTO 0|OFF Disables the frequency-related phase compensation. MANual Enables the 'Frequency in GHz' field for manual input of the carrier frequency value to be compensated. 1|AUTO Sets automatically the carrier 'Frequency in GHz' value to be compensated.
		"""
		param = Conversions.enum_scalar_to_str(rf_phase_comp, enums.PcmOdeAll)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:NODE:RFPHase:MODE {param}')



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ConfigCls:
	"""Config commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("config", core, parent)

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:GAP:CONFig:STATe \n
		Snippet: value: bool = driver.source.bb.eutra.downlink.niot.gap.config.get_state() \n
		If activated, a gap between the NPDCCH and NPDSCH with the specified duration is applied. \n
			:return: gap_config: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:NIOT:GAP:CONFig:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, gap_config: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:GAP:CONFig:STATe \n
		Snippet: driver.source.bb.eutra.downlink.niot.gap.config.set_state(gap_config = False) \n
		If activated, a gap between the NPDCCH and NPDSCH with the specified duration is applied. \n
			:param gap_config: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(gap_config)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:NIOT:GAP:CONFig:STATe {param}')



from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HoppingCls:
	"""Hopping commands group definition. 13 total commands, 5 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("hopping", core, parent)

	@property
	def frequency(self):
		"""frequency commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_frequency'):
			from .Frequency import FrequencyCls
			self._frequency = FrequencyCls(self._core, self._cmd_group)
		return self._frequency

	@property
	def offTime(self):
		"""offTime commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_offTime'):
			from .OffTime import OffTimeCls
			self._offTime = OffTimeCls(self._core, self._cmd_group)
		return self._offTime

	@property
	def ontime(self):
		"""ontime commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_ontime'):
			from .Ontime import OntimeCls
			self._ontime = OntimeCls(self._core, self._cmd_group)
		return self._ontime

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	@property
	def repetition(self):
		"""repetition commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_repetition'):
			from .Repetition import RepetitionCls
			self._repetition = RepetitionCls(self._core, self._cmd_group)
		return self._repetition

	def get_catalog(self) -> List[str]:
		"""SCPI: [SOURce<HW>]:PULM:TRAin:HOPPing:CATalog \n
		Snippet: value: List[str] = driver.source.pulm.train.hopping.get_catalog() \n
		No command help available \n
			:return: catalog: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:PULM:TRAin:HOPPing:CATalog?')
		return Conversions.str_to_str_list(response)

	def delete(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:PULM:TRAin:HOPPing:DELete \n
		Snippet: driver.source.pulm.train.hopping.delete(filename = 'abc') \n
		No command help available \n
			:param filename: No help available
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:PULM:TRAin:HOPPing:DELete {param}')

	def get_select(self) -> str:
		"""SCPI: [SOURce<HW>]:PULM:TRAin:HOPPing:SELect \n
		Snippet: value: str = driver.source.pulm.train.hopping.get_select() \n
		No command help available \n
			:return: filename: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:PULM:TRAin:HOPPing:SELect?')
		return trim_str_response(response)

	def set_select(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:PULM:TRAin:HOPPing:SELect \n
		Snippet: driver.source.pulm.train.hopping.set_select(filename = 'abc') \n
		No command help available \n
			:param filename: No help available
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:PULM:TRAin:HOPPing:SELect {param}')

	def clone(self) -> 'HoppingCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = HoppingCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HsupaCls:
	"""Hsupa commands group definition. 18 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("hsupa", core, parent)

	@property
	def eagch(self):
		"""eagch commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_eagch'):
			from .Eagch import EagchCls
			self._eagch = EagchCls(self._core, self._cmd_group)
		return self._eagch

	@property
	def ehich(self):
		"""ehich commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_ehich'):
			from .Ehich import EhichCls
			self._ehich = EhichCls(self._core, self._cmd_group)
		return self._ehich

	@property
	def ergch(self):
		"""ergch commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_ergch'):
			from .Ergch import ErgchCls
			self._ergch = ErgchCls(self._core, self._cmd_group)
		return self._ergch

	def clone(self) -> 'HsupaCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = HsupaCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal.Types import DataType
from ..........Internal.StructBase import StructBase
from ..........Internal.ArgStruct import ArgStruct
from ..........Internal.ArgSingleList import ArgSingleList
from ..........Internal.ArgSingle import ArgSingle
from .......... import enums
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DecimalCls:
	"""Decimal commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("decimal", core, parent)

	# noinspection PyTypeChecker
	class GetStruct(StructBase):
		"""Response structure. Fields: \n
			- Longitude: float: float Range: -180 to 180
			- Latitude: float: float Range: -90 to 90
			- Altitude: float: float Range: -10E3 to 50E6"""
		__meta_args_list = [
			ArgStruct.scalar_float('Longitude'),
			ArgStruct.scalar_float('Latitude'),
			ArgStruct.scalar_float('Altitude')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Longitude: float = None
			self.Latitude: float = None
			self.Altitude: float = None

	def get(self, time_basis: enums.TimeBasis, ycoorear: int, month: int, day: int, hour: int, minutes: int, seconds: float, week_number: int, time_of_week: float, vehicle=repcap.Vehicle.Default) -> GetStruct:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RT:RECeiver:[V<ST>]:RLOCation:COORdinates:DECimal \n
		Snippet: value: GetStruct = driver.source.bb.gnss.rt.receiver.v.rlocation.coordinates.decimal.get(time_basis = enums.TimeBasis.BDT, ycoorear = 1, month = 1, day = 1, hour = 1, minutes = 1, seconds = 1.0, week_number = 1, time_of_week = 1.0, vehicle = repcap.Vehicle.Default) \n
		Queries the coordinates of the receiver location in decimal format for the selected moment of time. The required query
		parameters depend on the selected timebase. \n
			:param time_basis: select
			:param ycoorear: No help available
			:param month: integer Range: 1 to 12
			:param day: integer Range: 1 to 31
			:param hour: integer Range: 0 to 23
			:param minutes: integer Range: 0 to 59
			:param seconds: float Range: 0 to 59.999
			:param week_number: integer Range: 0 to 529947
			:param time_of_week: float Range: 0 to 604799.999
			:param vehicle: optional repeated capability selector. Default value: Nr1 (settable in the interface 'V')
			:return: structure: for return value, see the help for GetStruct structure arguments."""
		param = ArgSingleList().compose_cmd_string(ArgSingle('time_basis', time_basis, DataType.Enum, enums.TimeBasis), ArgSingle('ycoorear', ycoorear, DataType.Integer), ArgSingle('month', month, DataType.Integer), ArgSingle('day', day, DataType.Integer), ArgSingle('hour', hour, DataType.Integer), ArgSingle('minutes', minutes, DataType.Integer), ArgSingle('seconds', seconds, DataType.Float), ArgSingle('week_number', week_number, DataType.Integer), ArgSingle('time_of_week', time_of_week, DataType.Float))
		vehicle_cmd_val = self._cmd_group.get_repcap_cmd_value(vehicle, repcap.Vehicle)
		return self._core.io.query_struct(f'SOURce<HwInstance>:BB:GNSS:RT:RECeiver:V{vehicle_cmd_val}:RLOCation:COORdinates:DECimal? {param}'.rstrip(), self.__class__.GetStruct())



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PowerCls:
	"""Power commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("power", core, parent)

	def get_att_digital(self) -> float:
		"""SCPI: [SOURce<HW>]:IQ:OUTPut:[ANALog]:POWer:ATTDigital \n
		Snippet: value: float = driver.source.iq.output.analog.power.get_att_digital() \n
		For [:SOURce<hw>]:IQ:OUTPut[:ANALog]:MODEVATTenuated, set the attenution with that the signal is attenuated. \n
			:return: dattenuation: float Range: -3.522 to 80
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:IQ:OUTPut:ANALog:POWer:ATTDigital?')
		return Conversions.str_to_float(response)

	def set_att_digital(self, dattenuation: float) -> None:
		"""SCPI: [SOURce<HW>]:IQ:OUTPut:[ANALog]:POWer:ATTDigital \n
		Snippet: driver.source.iq.output.analog.power.set_att_digital(dattenuation = 1.0) \n
		For [:SOURce<hw>]:IQ:OUTPut[:ANALog]:MODEVATTenuated, set the attenution with that the signal is attenuated. \n
			:param dattenuation: float Range: -3.522 to 80
		"""
		param = Conversions.decimal_value_to_str(dattenuation)
		self._core.io.write(f'SOURce<HwInstance>:IQ:OUTPut:ANALog:POWer:ATTDigital {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DirectoryCls:
	"""Directory commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("directory", core, parent)

	def clear(self) -> None:
		"""SCPI: HCOPy:FILE:[NAME]:AUTO:DIRectory:CLEar \n
		Snippet: driver.hardCopy.file.name.auto.directory.clear() \n
		Deletes all files with extensions *.bmp, *.jpg, *.png and *.xpm in the directory set for automatic naming. \n
		"""
		self._core.io.write(f'HCOPy:FILE:NAME:AUTO:DIRectory:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: HCOPy:FILE:[NAME]:AUTO:DIRectory:CLEar \n
		Snippet: driver.hardCopy.file.name.auto.directory.clear_with_opc() \n
		Deletes all files with extensions *.bmp, *.jpg, *.png and *.xpm in the directory set for automatic naming. \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsSmbv.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'HCOPy:FILE:NAME:AUTO:DIRectory:CLEar', opc_timeout_ms)

	def get_value(self) -> str:
		"""SCPI: HCOPy:FILE:[NAME]:AUTO:DIRectory \n
		Snippet: value: str = driver.hardCopy.file.name.auto.directory.get_value() \n
		Determines the path to save the hard copy, if you have enabled Automatic Naming. If the directory does not yet exist, the
		instrument automatically creates a new directory, using the instrument name and /var/user/ by default. \n
			:return: directory: string
		"""
		response = self._core.io.query_str('HCOPy:FILE:NAME:AUTO:DIRectory?')
		return trim_str_response(response)

	def set_value(self, directory: str) -> None:
		"""SCPI: HCOPy:FILE:[NAME]:AUTO:DIRectory \n
		Snippet: driver.hardCopy.file.name.auto.directory.set_value(directory = 'abc') \n
		Determines the path to save the hard copy, if you have enabled Automatic Naming. If the directory does not yet exist, the
		instrument automatically creates a new directory, using the instrument name and /var/user/ by default. \n
			:param directory: string
		"""
		param = Conversions.value_to_quoted_str(directory)
		self._core.io.write(f'HCOPy:FILE:NAME:AUTO:DIRectory {param}')
